{% raw %}
{% extends "base.html" %}
 {% load i18n %}

 {% block content %}
   <p>{% trans "Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one." %}</p>

   <form method="post">{% csrf_token %}
     {{ form.email.errors }}
     <p><label for="id_email">{% trans 'Email address:' %}</label>
       {{ form.email }}
       <button type="submit">{% trans 'Reset my password' %}</button></p>
   </form>
{% endblock %}
{% endraw %}
