{% raw %}
{% load i18n %}

<div>
  <form action="{% url 'search' %}">
    <input placeholder="{% trans "Looking for something?" %}" name="q" type="text" value="{{search_query}}">
    <input type="submit" value="{% trans "SEARCH"%}">
  </form>
</div>
{% endraw %}
