{% raw %}
{% load i18n wagtailadmin_tags staticfiles %}
<link rel="stylesheet" href="/static/css/layout.css">
<div class="panel nice-padding panel-upgrade-notification">
    <div class="help-block help-warning">
        <strong>Your site does not have a language.</strong>
        Click <a href="/admin/core/sitelanguage/create/">here</a> to add a language.
    </div>
</div>

{% endraw %}
