
def known_plugins():
    plugins = [('molo.core', 'Molo'), ('molo.profiles', 'Profiles'),
               ('molo.commenting', 'Commenting'), ('molo.polls', 'Polls'),
               ('molo.yourwords', 'YourWords'), ('molo.surveys', 'Surveys'),
               ('molo.servicedirectory', 'Service Directory')]

    return plugins
