{% raw %}
{% extends "base.html" %}

{% load static core_tags %}

{% block body_class %}template-{{ self.get_verbose_name|slugify }}{% endblock %}

{% block content %}
    {% section_listing_homepage %}
{% endblock %}
{% endraw %}
