# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-17 11:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0038_sitesettings_global_ga_tag_manager'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionpage',
            name='featured_in_homepage_rotation',
            field=models.BooleanField(default=False, help_text='This option allows articles featured in homepage to be rotatedrandomly and automatically for this section only'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='content_rotation',
            field=models.BooleanField(default=False, help_text='This option allows articles featured in latest to be rotatedrandomly and automatically'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='ga_tag_manager',
            field=models.CharField(blank=True, help_text='Local GA Tag Manager tracking code (e.g GTM-XXX) to be used to view analytics on this site only', max_length=255, null=True, verbose_name='Local GA Tag Manager'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='global_ga_tag_manager',
            field=models.CharField(blank=True, help_text='Global GA Tag Manager tracking code (e.g GTM-XXX) to be used to view analytics on more than one site globally', max_length=255, null=True, verbose_name='Global GA Tag Manager'),
        ),
    ]
