.versions{
  color: black;
  a {
    color: #cd3238;
  }
  table, th, td {
      border: 1px solid black;
  }
  th, td {
      padding: 5px;
      font-size: 14px;
  }
  th {
      text-align: left;
  }
  .latest{
    color: #20C320;
  }
  .plugin{
    font-weight: bold;
  }
  .not-installed{
    color: orange;
  }
}
