// Variables

$bodycolor: #fff;
$textcolor: #000;

// Typography

$font-family-sans-serif: "Open Sans", Helvetica, Arial, sans-serif;
$font-family-serif: Georgia, "Times New Roman", Times, serif;

// Colour - defaults

$colorFirst: #32a6a6; // turquoise
$colorSecond: #124f52; // dark turquoise
$colorThird: #c4d131; // green
$colorFourth: #333; // black
