{% raw %}
{% extends "base.html" %}
{% load i18n %}


{% block body %}
 <p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>

 <p><a href="{% url 'login' %}">{% trans 'Log in' %}</a></p>

{% endblock %}
{% endraw %}
