{% raw %}
{% load wagtailcore_tags wagtailimages_tags core_tags %}

{% if footers %}
  {% social_media_footer %}
  <ul>
  {% for page in footers %}
  <li><a href="{% pageurl page %}">{{page.title}}</a></li>
  {% endfor %}
  </ul>
{% endif %}
{% endraw %}
